@@ -2,7 +2,7 @@
  * Defines ethernet packet types, similar to tcpdump's ethertype.h
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@unicom.net>
+ * By Gerald Combs <gerald@zing.org>
  * Copyright 1998 Gerald Combs
  *
  * 
@@ -56,4 +56,8 @@
 #define ETHERTYPE_AARP 0x80f3
 #endif
 
+#ifndef ETHERTYPE_IPX
+#define ETHERTYPE_IPX 0x8137
+#endif
+
 #endif /* etypes.h */
