@@ -2,7 +2,7 @@
  * Routines for UDP packet disassembly
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@unicom.net>
+ * By Gerald Combs <gerald@zing.org>
  * Copyright 1998 Gerald Combs
  *
  * 
@@ -20,27 +20,32 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
+ 
+#include "config.h"
 
 #include <gtk/gtk.h>
 
-/* To do: do this correctly */
-#define __FAVOR_BSD
-
 #include <stdio.h>
-#include <netinet/in.h>
-#include <netinet/udp.h>
 
-#include "packet.h"
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+
+#ifdef _AIX
+#include <netinet/in.h>
+#endif
+
 #include "ethereal.h"
+#include "packet.h"
 
 void
 dissect_udp(const u_char *pd, int offset, frame_data *fd, GtkTree *tree) {
-  struct udphdr *uh;
-  guint16        uh_sport, uh_dport, uh_ulen, uh_sum;
-  GtkWidget     *udp_tree, *ti;
+  e_udphdr  *uh;
+  guint16    uh_sport, uh_dport, uh_ulen, uh_sum;
+  GtkWidget *udp_tree, *ti;
 
   /* To do: Check for {cap len,pkt len} < struct len */
-  uh = (struct udphdr *) &pd[offset];
+  uh = (e_udphdr *) &pd[offset];
   uh_sport = ntohs(uh->uh_sport);
   uh_dport = ntohs(uh->uh_dport);
   uh_ulen  = ntohs(uh->uh_ulen);
@@ -61,5 +66,9 @@ dissect_udp(const u_char *pd, int offset, frame_data *fd, GtkTree *tree) {
     add_item_to_tree(udp_tree, offset + 2, 2, "Destination port: %d", uh_dport);
     add_item_to_tree(udp_tree, offset + 4, 2, "Length: %d", uh_ulen);
     add_item_to_tree(udp_tree, offset + 6, 2, "Checksum: 0x%04x", uh_sum);
+
+    /* Skip over header */
+    offset += 8;
+    dissect_raw(pd, offset, fd, tree);
   }
 }
