@@ -2,7 +2,7 @@
  * Routines for packet disassembly
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@unicom.net>
+ * By Gerald Combs <gerald@zing.org>
  * Copyright 1998 Gerald Combs
  *
  * 
@@ -30,20 +30,14 @@
 #include <ctype.h>
 #include <netinet/in.h>
 
-/*
-#ifdef HAVE_NET_ETHERNET_H
-  #include <net/ethernet.h>
-#else
-  #include <sys/ethernet.h>
-#endif
-*/
-
 #include "packet.h"
 #include "ethereal.h"
 #include "etypes.h"
+#include "file.h"
 
 extern GtkWidget *byte_view;
 extern GdkFont   *m_r_font, *m_b_font;
+extern capture_file cf;
 
 gchar *
 ether_to_str(guint8 *ad) {
@@ -147,6 +141,8 @@ add_item_to_tree(GtkWidget *tree, gint start, gint len,
   guint32    t_info;
   
   /* This limits us to a max packet size of 65535 bytes. */
+  /* Are there any systems out there with < 32-bit pointers? */
+  /* To do: use gtk_object_set_data instead, now that I know it exists. */
   t_info = ((start & 0xffff) << 16) | (len & 0xffff);
   va_start(ap, format);
   vsnprintf(label_str, 256, format, ap);
@@ -158,91 +154,14 @@ add_item_to_tree(GtkWidget *tree, gint start, gint len,
   return ti;
 }
 
+/* this routine checks the frame type from the cf structure */
 void
 dissect_packet(const u_char *pd, frame_data *fd, GtkTree *tree) {
-  guint16    etype, length;
-  gchar      etype_str[][10] = {"IP", "ARP", "RARP", "AppleTalk", "AARP"};
-  int        offset = 14;
-  GtkWidget *fh_tree, *ti;
 
-  if (fd->win_info[0]) {
-    strcpy(fd->win_info[2], ether_to_str((guint8 *)&pd[0]));
-    strcpy(fd->win_info[1], ether_to_str((guint8 *)&pd[6]));
-    strcpy(fd->win_info[4], "Ethernet II");
-  }
-
-  etype = (pd[12] << 8) | pd[13];
-  if (etype <= IEEE_802_3_MAX_LEN) {
-    length = etype;
-    /* To do: check for 802.2 LLC and SNAP info */
-    etype  = (pd[20] << 8) | pd[21];
-    if (fd->win_info[0]) { sprintf(fd->win_info[4], "802.3 (0x%04x)", etype); }
-    if (tree) {
-      ti = add_item_to_tree(GTK_WIDGET(tree), 0, 22,
-        "IEEE 802.3 (%d on wire, %d captured)", fd->pkt_len, fd->cap_len);
-      fh_tree = gtk_tree_new();
-      gtk_tree_item_set_subtree(GTK_TREE_ITEM(ti), fh_tree);
-      add_item_to_tree(fh_tree, 0, 6, "Destination: %s",
-        ether_to_str((guint8 *) &pd[0]));
-      add_item_to_tree(fh_tree, 6, 6, "Source: %s",
-        ether_to_str((guint8 *) &pd[6]));
-      add_item_to_tree(fh_tree, 12, 2, "Length: %d", length);
-      add_item_to_tree(fh_tree, 14, 3, "802.2 LLC: 0x%02x/0x%02x/0x%02x",
-        pd[14], pd[15], pd[16]);
-    }
-    offset = 22;
-  } else if (tree) {
-    ti = add_item_to_tree(GTK_WIDGET(tree), 0, 14,
-      "Ethernet II (%d on wire, %d captured)", fd->pkt_len, fd->cap_len);
-    fh_tree = gtk_tree_new();
-    gtk_tree_item_set_subtree(GTK_TREE_ITEM(ti), fh_tree);
-    add_item_to_tree(fh_tree, 0, 6, "Destination: %s",
-      ether_to_str((guint8 *) &pd[0]));
-    add_item_to_tree(fh_tree, 6, 6, "Source: %s",
-      ether_to_str((guint8 *) &pd[6]));
-  }
-  
-  switch (etype) {
-    case ETHERTYPE_IP:
-      if (tree) {
-        add_item_to_tree(fh_tree, offset - 2, 2, "Type: IP (0x%04x)",
-          etype);
-      }
-      dissect_ip(pd, offset, fd, tree);
-      break;
-    case ETHERTYPE_ARP:
-      if (tree) {
-        add_item_to_tree(fh_tree, offset - 2, 2,
-          "Type: ARP (0x%04x)", etype);
-      }
-      dissect_arp(pd, offset, fd, tree);
-      break;
-    case ETHERTYPE_REVARP:
-      if (tree) {
-        add_item_to_tree(fh_tree, offset - 2, 2,
-          "Type: RARP (0x%04x)", etype);
-      }
-      dissect_arp(pd, offset, fd, tree);
-      break;
-    case ETHERTYPE_ATALK:
-      if (tree) {
-        add_item_to_tree(fh_tree, offset - 2, 2,
-          "Type: AppleTalk (0x%04x)", etype);
-      }
-      if (fd->win_info[0]) { strcpy(fd->win_info[3], etype_str[3]); }
-      break;
-    case ETHERTYPE_AARP:
-      if (tree) {
-        add_item_to_tree(fh_tree, offset - 2, 2,
-          "Type: AARP (0x%04x)", etype);
-      }
-      if (fd->win_info[0]) { strcpy(fd->win_info[3], etype_str[4]); }
-      break;
-    default:
-      if (tree)
-        add_item_to_tree(fh_tree, offset - 2, 2,
-          "Type: Unknown (0x%04x)", etype);
-      if (fd->win_info[0]) { sprintf(fd->win_info[3], "0x%04x", etype); }
-      break;
-  }
+	if (cf.lnk_t == LT_ETHER10) {
+		dissect_eth(pd, fd, tree);
+	}
+	else if (cf.lnk_t == LT_IEEE802) {
+		dissect_tr(pd, fd, tree);
+	}
 }
